#!/usr/bin/env python3

import os
import sys

from PyQt5.QtCore import QTranslator, QLocale, QLibraryInfo
from PyQt5.QtWidgets import QApplication, QMessageBox

from astra_installer.utils import Utils as BackendUtils
from astra_installer_qt.utils import Utils as InstallerUtils
from astra_installer_qt_oem_integration.mainwindow import MainWindow
from astra_installer_qt_oem_integration.utils import Utils
from astra_installer_qt_oem.arg_parser import create_arg_parser
from astra_installer.settings.system_locale import Locale

translate = QApplication.translate


def main() -> None:
    app = QApplication(sys.argv)

    lang = BackendUtils.get_lang()
    locale = Locale.from_string(lang).language_and_territory()
    sys_translator = QTranslator(app)
    app_translator = QTranslator(app)
    sys_translator.load('qt_' + locale, QLibraryInfo.location(QLibraryInfo.TranslationsPath))
    app_translator.load(QLocale(locale), '', '', InstallerUtils.file_path('translations'), '.qm')
    app.installTranslator(sys_translator)
    app.installTranslator(app_translator)

    if os.getuid() != 0:
        QMessageBox.critical(None, translate('text', 'Unprivileged user'),
                             translate('text', 'You run the program under an unprivileged user, '
                                               'which means that you can not enable or disable OEM integration mode. '
                                               'Please run the program under the root user.'))
        sys.exit(0)
    if not Utils.is_current_process_has_max_mic():
        QMessageBox.critical(None, translate('text', 'Wrong integrity level'),
                             translate('text', 'The operating system is running in the mandatory '
                                               'integrity control mode. To manage the OEM integration mode, '
                                               'you should login with a high level of integrity.'))
        sys.exit(0)

    parser = create_arg_parser()
    arguments = parser.parse_args()

    main_window = MainWindow(arguments.hide_eula_page)
    main_window.show()
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()
